# Pygame Enhancer

This is a simple Python library that allows you to enhance the performance of pygame, fixing many bugs such as Screen Tearing.

## Installation

To install this package, run:

python3 -m pip install PygameEnhanced